"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RegistrationActions = void 0;
/**
 * @packageDocumentation
 * @module RegistrationUIContext
 */

/**
 * Named dispatch actions for account-related global state changes (i.e. load EULA, validate invite registration request, complete registration).
 */
const RegistrationActions = {
  loadEulaReset: () => ({
    type: 'Registration/LoadEula/Reset'
  }),
  loadEulaStarted: (transitId, language) => ({
    type: 'Registration/LoadEula/Started',
    payload: {
      transitId,
      language
    }
  }),
  loadEulaSucceeded: transitId => ({
    type: 'Registration/LoadEula/Succeeded',
    payload: {
      transitId
    }
  }),
  loadEulaFailed: (transitId, errorMessage) => ({
    type: 'Registration/LoadEula/Failed',
    payload: {
      transitId,
      errorMessage
    }
  }),
  requestRegistrationCodeReset: () => ({
    type: 'Registration/RequestCode/Reset'
  }),
  requestRegistrationCodeStarted: transitId => ({
    type: 'Registration/RequestCode/Started',
    payload: {
      transitId
    }
  }),
  requestRegistrationCodeSucceeded: transitId => ({
    type: 'Registration/RequestCode/Succeeded',
    payload: {
      transitId
    }
  }),
  requestRegistrationCodeFailed: (transitId, errorMessage) => ({
    type: 'Registration/RequestCode/Failed',
    payload: {
      transitId,
      errorMessage
    }
  }),
  validateUserRegistrationReset: () => ({
    type: 'Registration/ValidateUser/Reset'
  }),
  validateUserRegistrationStarted: transitId => ({
    type: 'Registration/ValidateUser/Started',
    payload: {
      transitId
    }
  }),
  validateUserRegistrationSucceeded: transitId => ({
    type: 'Registration/ValidateUser/Succeeded',
    payload: {
      transitId
    }
  }),
  validateUserRegistrationFailed: (transitId, errorMessage) => ({
    type: 'Registration/ValidateUser/Failed',
    payload: {
      transitId,
      errorMessage
    }
  }),
  registerUserReset: () => ({
    type: 'Registration/RegisterUser/Reset'
  }),
  registerUserStarted: transitId => ({
    type: 'Registration/RegisterUser/Started',
    payload: {
      transitId
    }
  }),
  registerUserSucceeded: (transitId, email, organizationName) => ({
    type: 'Registration/RegisterUser/Succeeded',
    payload: {
      transitId,
      email,
      organizationName
    }
  }),
  registerUserFailed: (transitId, errorMessage) => ({
    type: 'Registration/RegisterUser/Failed',
    payload: {
      transitId,
      errorMessage
    }
  })
};
exports.RegistrationActions = RegistrationActions;
//# sourceMappingURL=dispatchActions.js.map