import { subMilliseconds, differenceInMilliseconds } from 'date-fns';
let timeTravelOffset = 0;
let frozenTime;
const internalNow = () => {
  if (frozenTime) {
    return frozenTime;
  }
  return subMilliseconds(new Date(), timeTravelOffset);
};
const now = () => {
  return internalNow();
};
const assertInTest = () => {
  if (process.env.NODE_ENV !== 'test') {
    throw new Error('Time travel is only allowed in tests!');
  }
};
const timeTravel = async time => {
  assertInTest();
  timeTravelOffset = differenceInMilliseconds(new Date(), typeof time === 'string' ? new Date(time) : time);
  frozenTime = undefined;
};
const restoreTime = async () => {
  assertInTest();
  timeTravelOffset = 0;
  frozenTime = undefined;
};
const freezeTime = async time => {
  assertInTest();
  if (time) {
    await timeTravel(time);
  }
  frozenTime = internalNow();
};
const unfreezeTime = async () => {
  assertInTest();
  frozenTime = undefined;
};
export const Clock = {
  now,
  Testing: {
    timeTravel,
    restoreTime,
    freezeTime,
    unfreezeTime
  }
};
//# sourceMappingURL=clock.js.map